/*
   mkvpropedit -- utility for editing properties of existing Matroska files

   Distributed under the GPL
   see the file COPYING for details
   or visit http://www.gnu.org/copyleft/gpl.html

   Written by Moritz Bunkus <moritz@bunkus.org>.
*/

#ifndef __PROPEDIT_PROPEDIT_H
#define __PROPEDIT_PROPEDIT_H

#include "common/os.h"

#include "common/common_pch.h"

#define FILE_NOT_MODIFIED Y("The file has not been modified.")

#endif // __PROPEDIT_PROPEDIT_H
